@@ -14,7 +14,7 @@
 #'  prevent very small tolerances in rare taxa.
 #' This function is very similar to the \code{\link[analogue]{caterpillar}}
 #'  plot, but produces a ggplot
-#' @return A \code{\link[ggplot2]{ggplot}} object.
+#' @returns A \code{\link[ggplot2]{ggplot}} object.
 #'
 #' @examples
 #' library(rioja)
@@ -62,5 +62,5 @@ centipede_plot <- function(x, spp, minN2 = 1, mult = 1) {
     geom_point() +
     coord_flip()
 
-  return(g)
+  g
 }
