@@ -34,9 +34,9 @@
 #' variables and the species first axis scores.
 #' This option has some pathological behaviour and should probably be avoided.
 #'
-#' @return
+#' @returns
 #'  A list with components
-#' \itemize{
+#'
 #'  \item{PCA}{ The unconstrained ordination of the fossil data.}
 #'  \item{preds}{ A list of the containing the reconstructions for each
 #'  environmental variable.}
@@ -48,7 +48,7 @@
 #'  \item{sim.ex}{ The proportion of variance explained by each of the random
 #'  environmental variables.}
 #'  \item{sig}{ The p-value of each reconstruction.}
-#' }
+#'
 #'
 #' @references Unpublished method - use with caution. Can give spurious results
 #' with weighted averaging.
@@ -101,5 +101,5 @@ jointsig <- function(spp, fos, var1, var2,
   res$v1 <- v1
   res$v2 <- v2
   class(res) <- "js"
-  return(res)
+  res
 }
