@@ -26,13 +26,12 @@
 #' This is no longer done as the variance is small for large training sets,
 #' it took a long time, and treats one treatment of the data differently.
 
-#' @return
+#' @returns
 #' Returns an RNE object, list with two components
-#' \itemize{
 #'  \item{random }{Performance with random deletion.}
 #'  \item{neighbour }{Performance with deletion by neighbourhood,
 #'  or environment}
-#'  }
+#'
 #' @references Telford, R. J. and Birks, H. J. B. (2009) Evaluation of transfer
 #' functions in spatially structured environments.
 #' \emph{Quaternary Science Reviews} \bold{28}: 1309--1316.
@@ -45,7 +44,8 @@
 #' data(arctic.env)
 #' data(arctic.pollen)
 #'
-#' # using just the first 100 sites so that code runs quickly (about 15 seconds for all 828 sites)
+#' # using just the first 100 sites so that code runs quickly
+#' # (about 15 seconds for all 828 sites)
 #'
 #' # convert environmental data into an sf object
 #' arctic.env <- st_as_sf(
@@ -186,5 +186,5 @@ rne <- function(y, env, geodist, fun, neighbours,
   })
 
   class(rne) <- "RNE"
-  return(rne)
+  rne
 }
